####################
  Neville Usage
####################

This contains exampes of how to generate data for the CNN to train and examples of how to train a model.


.. toctree::
    :maxdepth: 2

    load_model.rst

